==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Spatial_searching/examples.js <==
var examples =
[
    [ "Spatial_searching/circular_query.cpp", "Spatial_searching_2circular_query_8cpp-example.html", null ],
    [ "Spatial_searching/Distance.h", "Spatial_searching_2Distance_8h-example.html", null ],
    [ "Spatial_searching/distance_browsing.cpp", "Spatial_searching_2distance_browsing_8cpp-example.html", null ],
    [ "Spatial_searching/fuzzy_range_query.cpp", "Spatial_searching_2fuzzy_range_query_8cpp-example.html", null ],
    [ "Spatial_searching/general_neighbor_searching.cpp", "Spatial_searching_2general_neighbor_searching_8cpp-example.html", null ],
    [ "Spatial_searching/iso_rectangle_2_query.cpp", "Spatial_searching_2iso_rectangle_2_query_8cpp-example.html", null ],
    [ "Spatial_searching/iso_rectangle_2_query_projection.cpp", "Spatial_searching_2iso_rectangle_2_query_projection_8cpp-example.html", null ],
    [ "Spatial_searching/nearest_neighbor_searching.cpp", "Spatial_searching_2nearest_neighbor_searching_8cpp-example.html", null ],
    [ "Spatial_searching/parallel_kdtree.cpp", "Spatial_searching_2parallel_kdtree_8cpp-example.html", null ],
    [ "Spatial_searching/Point.h", "Spatial_searching_2Point_8h-example.html", null ],
    [ "Spatial_searching/searching_polyhedron_vertices.cpp", "Spatial_searching_2searching_polyhedron_vertices_8cpp-example.html", null ],
    [ "Spatial_searching/searching_sphere_orthogonally.cpp", "Spatial_searching_2searching_sphere_orthogonally_8cpp-example.html", null ],
    [ "Spatial_searching/searching_surface_mesh_vertices.cpp", "Spatial_searching_2searching_surface_mesh_vertices_8cpp-example.html", null ],
    [ "Spatial_searching/searching_with_circular_query.cpp", "Spatial_searching_2searching_with_circular_query_8cpp-example.html", null ],
    [ "Spatial_searching/searching_with_point_with_info.cpp", "Spatial_searching_2searching_with_point_with_info_8cpp-example.html", null ],
    [ "Spatial_searching/searching_with_point_with_info_inplace.cpp", "Spatial_searching_2searching_with_point_with_info_inplace_8cpp-example.html", null ],
    [ "Spatial_searching/searching_with_point_with_info_pmap.cpp", "Spatial_searching_2searching_with_point_with_info_pmap_8cpp-example.html", null ],
    [ "Spatial_searching/splitter_worst_cases.cpp", "Spatial_searching_2splitter_worst_cases_8cpp-example.html", null ],
    [ "Spatial_searching/user_defined_point_and_distance.cpp", "Spatial_searching_2user_defined_point_and_distance_8cpp-example.html", null ],
    [ "Spatial_searching/using_fair_splitting_rule.cpp", "Spatial_searching_2using_fair_splitting_rule_8cpp-example.html", null ],
    [ "Spatial_searching/weighted_Minkowski_distance.cpp", "Spatial_searching_2weighted_Minkowski_distance_8cpp-example.html", null ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Spatial_searching/examples.js <==
var examples =
[
    [ "Spatial_searching/Point.h", "Spatial_searching_2Point_8h-example.html", null ],
    [ "Spatial_searching/Distance.h", "Spatial_searching_2Distance_8h-example.html", null ],
    [ "Spatial_searching/circular_query.cpp", "Spatial_searching_2circular_query_8cpp-example.html", null ],
    [ "Spatial_searching/distance_browsing.cpp", "Spatial_searching_2distance_browsing_8cpp-example.html", null ],
    [ "Spatial_searching/fuzzy_range_query.cpp", "Spatial_searching_2fuzzy_range_query_8cpp-example.html", null ],
    [ "Spatial_searching/general_neighbor_searching.cpp", "Spatial_searching_2general_neighbor_searching_8cpp-example.html", null ],
    [ "Spatial_searching/iso_rectangle_2_query.cpp", "Spatial_searching_2iso_rectangle_2_query_8cpp-example.html", null ],
    [ "Spatial_searching/iso_rectangle_2_query_projection.cpp", "Spatial_searching_2iso_rectangle_2_query_projection_8cpp-example.html", null ],
    [ "Spatial_searching/nearest_neighbor_searching.cpp", "Spatial_searching_2nearest_neighbor_searching_8cpp-example.html", null ],
    [ "Spatial_searching/searching_with_circular_query.cpp", "Spatial_searching_2searching_with_circular_query_8cpp-example.html", null ],
    [ "Spatial_searching/searching_surface_mesh_vertices.cpp", "Spatial_searching_2searching_surface_mesh_vertices_8cpp-example.html", null ],
    [ "Spatial_searching/searching_polyhedron_vertices.cpp", "Spatial_searching_2searching_polyhedron_vertices_8cpp-example.html", null ],
    [ "Spatial_searching/searching_triangulation_vertices.cpp", "Spatial_searching_2searching_triangulation_vertices_8cpp-example.html", null ],
    [ "Spatial_searching/searching_with_point_with_info.cpp", "Spatial_searching_2searching_with_point_with_info_8cpp-example.html", null ],
    [ "Spatial_searching/searching_with_point_with_info_inplace.cpp", "Spatial_searching_2searching_with_point_with_info_inplace_8cpp-example.html", null ],
    [ "Spatial_searching/searching_with_point_with_info_pmap.cpp", "Spatial_searching_2searching_with_point_with_info_pmap_8cpp-example.html", null ],
    [ "Spatial_searching/user_defined_point_and_distance.cpp", "Spatial_searching_2user_defined_point_and_distance_8cpp-example.html", null ],
    [ "Spatial_searching/using_fair_splitting_rule.cpp", "Spatial_searching_2using_fair_splitting_rule_8cpp-example.html", null ],
    [ "Spatial_searching/weighted_Minkowski_distance.cpp", "Spatial_searching_2weighted_Minkowski_distance_8cpp-example.html", null ],
    [ "Spatial_searching/splitter_worst_cases.cpp", "Spatial_searching_2splitter_worst_cases_8cpp-example.html", null ],
    [ "Spatial_searching/searching_sphere_orthogonally.cpp", "Spatial_searching_2searching_sphere_orthogonally_8cpp-example.html", null ],
    [ "Spatial_searching/parallel_kdtree.cpp", "Spatial_searching_2parallel_kdtree_8cpp-example.html", null ]
];
